@@ -1,4 +1,5 @@
 """Define an object to work directly with the API."""
+
 from __future__ import annotations
 
 import asyncio
@@ -26,7 +27,7 @@ DEFAULT_USER_AGENT = "Tile/4774 CFNetwork/1312 Darwin/21.0.0"
 class API:
     """Define the API management object."""
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         email: str,
         password: str,
@@ -80,18 +81,16 @@ class API:
         kwargs["headers"]["tile_app_version"] = DEFAULT_APP_VERSION
         kwargs["headers"]["tile_client_uuid"] = self.client_uuid
 
-        async with self._session.request(
-            method, f"{API_URL_SCAFFOLD}/{endpoint}", **kwargs
-        ) as resp:
-            try:
+        try:
+            async with self._session.request(
+                method, f"{API_URL_SCAFFOLD}/{endpoint}", **kwargs
+            ) as resp:
                 resp.raise_for_status()
                 data = await resp.json()
-            except ClientError as err:
-                if "401" in str(err):
-                    raise InvalidAuthError("Invalid credentials") from err
-                raise RequestError(
-                    f"Error requesting data from {endpoint}: {err}"
-                ) from err
+        except ClientError as err:
+            if "401" in str(err):
+                raise InvalidAuthError("Invalid credentials") from err
+            raise RequestError(f"Error requesting data from {endpoint}: {err}") from err
 
         LOGGER.debug("Data received from /%s: %s", endpoint, data)
 
@@ -114,12 +113,14 @@ class API:
 
         data = {}
         for tile_uuid, result in zip(details_tasks, results):
-            if isinstance(result, RequestError):
-                if "412" in str(result):
-                    # Tile Labels will return an HTTP 412 because they don't have
-                    # additional details; we can safely ignore these errors and still
-                    # track the Tile (without additional details):
-                    continue
+            if isinstance(result, RequestError) and "412" in str(result):
+                # Tile Labels will return an HTTP 412 because they don't have
+                # additional details; we can safely ignore these errors and still
+                # track the Tile (without additional details):
+                continue
+            if isinstance(result, BaseException):
+                LOGGER.error("Error requesting details for %s: %s", tile_uuid, result)
+                continue
             data[tile_uuid] = Tile(self._async_request, result)
 
         return data
